Struct objc2_quartz_core::CAEmitterCell

source ·
#[repr(C)]
pub struct CAEmitterCell { /* private fields */ }
Available on crate feature CAEmitterCell only.

Implementations

source

impl CAEmitterCell

source

pub unsafe fn emitterCell() -> Retained<Self>

source

pub unsafe fn defaultValueForKey(key: &NSString) -> Option<Retained<AnyObject>>

source

pub unsafe fn shouldArchiveValueForKey(&self, key: &NSString) -> bool

source

pub unsafe fn name(&self) -> Option<Retained<NSString>>

source

pub unsafe fn setName(&self, name: Option<&NSString>)

source

pub unsafe fn isEnabled(&self) -> bool

source

pub unsafe fn setEnabled(&self, enabled: bool)

source

pub unsafe fn birthRate(&self) -> c_float

source

pub unsafe fn setBirthRate(&self, birth_rate: c_float)

source

pub unsafe fn lifetime(&self) -> c_float

source

pub unsafe fn setLifetime(&self, lifetime: c_float)

source

pub unsafe fn lifetimeRange(&self) -> c_float

source

pub unsafe fn setLifetimeRange(&self, lifetime_range: c_float)

source

pub unsafe fn emissionLatitude(&self) -> CGFloat

source

pub unsafe fn setEmissionLatitude(&self, emission_latitude: CGFloat)

source

pub unsafe fn emissionLongitude(&self) -> CGFloat

source

pub unsafe fn setEmissionLongitude(&self, emission_longitude: CGFloat)

source

pub unsafe fn emissionRange(&self) -> CGFloat

source

pub unsafe fn setEmissionRange(&self, emission_range: CGFloat)

source

pub unsafe fn velocity(&self) -> CGFloat

source

pub unsafe fn setVelocity(&self, velocity: CGFloat)

source

pub unsafe fn velocityRange(&self) -> CGFloat

source

pub unsafe fn setVelocityRange(&self, velocity_range: CGFloat)

source

pub unsafe fn xAcceleration(&self) -> CGFloat

source

pub unsafe fn setXAcceleration(&self, x_acceleration: CGFloat)

source

pub unsafe fn yAcceleration(&self) -> CGFloat

source

pub unsafe fn setYAcceleration(&self, y_acceleration: CGFloat)

source

pub unsafe fn zAcceleration(&self) -> CGFloat

source

pub unsafe fn setZAcceleration(&self, z_acceleration: CGFloat)

source

pub unsafe fn scale(&self) -> CGFloat

source

pub unsafe fn setScale(&self, scale: CGFloat)

source

pub unsafe fn scaleRange(&self) -> CGFloat

source

pub unsafe fn setScaleRange(&self, scale_range: CGFloat)

source

pub unsafe fn scaleSpeed(&self) -> CGFloat

source

pub unsafe fn setScaleSpeed(&self, scale_speed: CGFloat)

source

pub unsafe fn spin(&self) -> CGFloat

source

pub unsafe fn setSpin(&self, spin: CGFloat)

source

pub unsafe fn spinRange(&self) -> CGFloat

source

pub unsafe fn setSpinRange(&self, spin_range: CGFloat)

source

pub unsafe fn redRange(&self) -> c_float

source

pub unsafe fn setRedRange(&self, red_range: c_float)

source

pub unsafe fn greenRange(&self) -> c_float

source

pub unsafe fn setGreenRange(&self, green_range: c_float)

source

pub unsafe fn blueRange(&self) -> c_float

source

pub unsafe fn setBlueRange(&self, blue_range: c_float)

source

pub unsafe fn alphaRange(&self) -> c_float

source

pub unsafe fn setAlphaRange(&self, alpha_range: c_float)

source

pub unsafe fn redSpeed(&self) -> c_float

source

pub unsafe fn setRedSpeed(&self, red_speed: c_float)

source

pub unsafe fn greenSpeed(&self) -> c_float

source

pub unsafe fn setGreenSpeed(&self, green_speed: c_float)

source

pub unsafe fn blueSpeed(&self) -> c_float

source

pub unsafe fn setBlueSpeed(&self, blue_speed: c_float)

source

pub unsafe fn alphaSpeed(&self) -> c_float

source

pub unsafe fn setAlphaSpeed(&self, alpha_speed: c_float)

source

pub unsafe fn contents(&self) -> Option<Retained<AnyObject>>

source

pub unsafe fn setContents(&self, contents: Option<&AnyObject>)

source

pub unsafe fn contentsRect(&self) -> CGRect

source

pub unsafe fn setContentsRect(&self, contents_rect: CGRect)

source

pub unsafe fn contentsScale(&self) -> CGFloat

source

pub unsafe fn setContentsScale(&self, contents_scale: CGFloat)

source

pub unsafe fn minificationFilter(&self) -> Retained<NSString>

source

pub unsafe fn setMinificationFilter(&self, minification_filter: &NSString)

source

pub unsafe fn magnificationFilter(&self) -> Retained<NSString>

source

pub unsafe fn setMagnificationFilter(&self, magnification_filter: &NSString)

source

pub unsafe fn minificationFilterBias(&self) -> c_float

source

pub unsafe fn setMinificationFilterBias( &self, minification_filter_bias: c_float )

source

pub unsafe fn emitterCells(&self) -> Option<Retained<NSArray<CAEmitterCell>>>

source

pub unsafe fn setEmitterCells( &self, emitter_cells: Option<&NSArray<CAEmitterCell>> )

source

pub unsafe fn style(&self) -> Option<Retained<NSDictionary>>

source

pub unsafe fn setStyle(&self, style: Option<&NSDictionary>)

source

impl CAEmitterCell

Methods declared on superclass NSObject

source

pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>

source

pub unsafe fn new() -> Retained<Self>

Methods from Deref<Target = NSObject>

source

pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !

Handle messages the object doesn’t recognize.

See Apple’s documentation for details.

Methods from Deref<Target = AnyObject>

source

pub fn class(&self) -> &'static AnyClass

Dynamically find the class of this object.

Example

Check that an instance of NSObject has the precise class NSObject.

use objc2::ClassType;
use objc2::runtime::NSObject;

let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());
source

pub unsafe fn get_ivar<T>(&self, name: &str) -> &T
where T: Encode,

👎Deprecated: this is difficult to use correctly, use Ivar::load instead.

Use Ivar::load instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.

source

pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut T
where T: Encode,

👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.

Use Ivar::load_mut instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.