Struct objc2_quartz_core::CALayer

source ·
#[repr(C)]
pub struct CALayer { /* private fields */ }
Available on crate feature CALayer only.

Implementations

source

impl CALayer

CAConstraintLayoutManager

source

pub unsafe fn constraints(&self) -> Option<Retained<NSArray<CAConstraint>>>

Available on crate feature CAConstraintLayoutManager only.
source

pub unsafe fn setConstraints(&self, constraints: Option<&NSArray<CAConstraint>>)

Available on crate feature CAConstraintLayoutManager only.
source

pub unsafe fn addConstraint(&self, c: &CAConstraint)

Available on crate feature CAConstraintLayoutManager only.
source

impl CALayer

source

pub fn layer() -> Retained<Self>

source

pub fn init(this: Allocated<Self>) -> Retained<Self>

source

pub unsafe fn initWithLayer( this: Allocated<Self>, layer: &AnyObject ) -> Retained<Self>

source

pub unsafe fn presentationLayer(&self) -> Option<Retained<Self>>

source

pub unsafe fn modelLayer(&self) -> Retained<Self>

source

pub unsafe fn defaultValueForKey(key: &NSString) -> Option<Retained<AnyObject>>

source

pub unsafe fn needsDisplayForKey(key: &NSString) -> bool

source

pub unsafe fn shouldArchiveValueForKey(&self, key: &NSString) -> bool

source

pub fn bounds(&self) -> CGRect

source

pub fn setBounds(&self, bounds: CGRect)

source

pub fn position(&self) -> CGPoint

source

pub fn setPosition(&self, position: CGPoint)

source

pub fn zPosition(&self) -> CGFloat

source

pub fn setZPosition(&self, z_position: CGFloat)

source

pub fn anchorPoint(&self) -> CGPoint

source

pub fn setAnchorPoint(&self, anchor_point: CGPoint)

source

pub fn anchorPointZ(&self) -> CGFloat

source

pub fn setAnchorPointZ(&self, anchor_point_z: CGFloat)

source

pub fn transform(&self) -> CATransform3D

Available on crate feature CATransform3D only.
source

pub fn setTransform(&self, transform: CATransform3D)

Available on crate feature CATransform3D only.
source

pub fn frame(&self) -> CGRect

source

pub fn setFrame(&self, frame: CGRect)

source

pub fn isHidden(&self) -> bool

source

pub fn setHidden(&self, hidden: bool)

source

pub fn isDoubleSided(&self) -> bool

source

pub fn setDoubleSided(&self, double_sided: bool)

source

pub fn isGeometryFlipped(&self) -> bool

source

pub fn setGeometryFlipped(&self, geometry_flipped: bool)

source

pub fn contentsAreFlipped(&self) -> bool

source

pub fn superlayer(&self) -> Option<Retained<CALayer>>

source

pub fn removeFromSuperlayer(&self)

source

pub unsafe fn sublayers(&self) -> Option<Retained<NSArray<CALayer>>>

source

pub unsafe fn setSublayers(&self, sublayers: Option<&NSArray<CALayer>>)

source

pub fn addSublayer(&self, layer: &CALayer)

source

pub fn insertSublayer_atIndex(&self, layer: &CALayer, idx: c_uint)

source

pub fn insertSublayer_below(&self, layer: &CALayer, sibling: Option<&CALayer>)

source

pub fn insertSublayer_above(&self, layer: &CALayer, sibling: Option<&CALayer>)

source

pub unsafe fn replaceSublayer_with( &self, old_layer: &CALayer, new_layer: &CALayer )

source

pub fn sublayerTransform(&self) -> CATransform3D

Available on crate feature CATransform3D only.
source

pub fn setSublayerTransform(&self, sublayer_transform: CATransform3D)

Available on crate feature CATransform3D only.
source

pub fn mask(&self) -> Option<Retained<CALayer>>

source

pub unsafe fn setMask(&self, mask: Option<&CALayer>)

source

pub fn masksToBounds(&self) -> bool

source

pub fn setMasksToBounds(&self, masks_to_bounds: bool)

source

pub fn convertPoint_fromLayer(&self, p: CGPoint, l: Option<&CALayer>) -> CGPoint

source

pub fn convertPoint_toLayer(&self, p: CGPoint, l: Option<&CALayer>) -> CGPoint

source

pub fn convertRect_fromLayer(&self, r: CGRect, l: Option<&CALayer>) -> CGRect

source

pub fn convertRect_toLayer(&self, r: CGRect, l: Option<&CALayer>) -> CGRect

source

pub fn convertTime_fromLayer( &self, t: c_double, l: Option<&CALayer> ) -> c_double

source

pub fn convertTime_toLayer(&self, t: c_double, l: Option<&CALayer>) -> c_double

source

pub fn hitTest(&self, p: CGPoint) -> Option<Retained<CALayer>>

source

pub fn containsPoint(&self, p: CGPoint) -> bool

source

pub unsafe fn contents(&self) -> Option<Retained<AnyObject>>

source

pub unsafe fn setContents(&self, contents: Option<&AnyObject>)

source

pub fn contentsRect(&self) -> CGRect

source

pub fn setContentsRect(&self, contents_rect: CGRect)

source

pub fn contentsGravity(&self) -> Retained<CALayerContentsGravity>

source

pub fn setContentsGravity(&self, contents_gravity: &CALayerContentsGravity)

source

pub fn contentsScale(&self) -> CGFloat

source

pub fn setContentsScale(&self, contents_scale: CGFloat)

source

pub fn contentsCenter(&self) -> CGRect

source

pub fn setContentsCenter(&self, contents_center: CGRect)

source

pub fn contentsFormat(&self) -> Retained<CALayerContentsFormat>

source

pub fn setContentsFormat(&self, contents_format: &CALayerContentsFormat)

source

pub unsafe fn wantsExtendedDynamicRangeContent(&self) -> bool

source

pub unsafe fn setWantsExtendedDynamicRangeContent( &self, wants_extended_dynamic_range_content: bool )

source

pub fn minificationFilter(&self) -> Retained<CALayerContentsFilter>

source

pub fn setMinificationFilter(&self, minification_filter: &CALayerContentsFilter)

source

pub fn magnificationFilter(&self) -> Retained<CALayerContentsFilter>

source

pub fn setMagnificationFilter( &self, magnification_filter: &CALayerContentsFilter )

source

pub fn minificationFilterBias(&self) -> c_float

source

pub fn setMinificationFilterBias(&self, minification_filter_bias: c_float)

source

pub fn isOpaque(&self) -> bool

source

pub fn setOpaque(&self, opaque: bool)

source

pub fn display(&self)

source

pub fn setNeedsDisplay(&self)

source

pub fn setNeedsDisplayInRect(&self, r: CGRect)

source

pub fn needsDisplay(&self) -> bool

source

pub fn displayIfNeeded(&self)

source

pub fn needsDisplayOnBoundsChange(&self) -> bool

source

pub fn setNeedsDisplayOnBoundsChange( &self, needs_display_on_bounds_change: bool )

source

pub fn drawsAsynchronously(&self) -> bool

source

pub fn setDrawsAsynchronously(&self, draws_asynchronously: bool)

source

pub fn edgeAntialiasingMask(&self) -> CAEdgeAntialiasingMask

source

pub fn setEdgeAntialiasingMask( &self, edge_antialiasing_mask: CAEdgeAntialiasingMask )

source

pub fn allowsEdgeAntialiasing(&self) -> bool

source

pub fn setAllowsEdgeAntialiasing(&self, allows_edge_antialiasing: bool)

source

pub fn cornerRadius(&self) -> CGFloat

source

pub fn setCornerRadius(&self, corner_radius: CGFloat)

source

pub fn maskedCorners(&self) -> CACornerMask

source

pub fn setMaskedCorners(&self, masked_corners: CACornerMask)

source

pub fn cornerCurve(&self) -> Retained<CALayerCornerCurve>

source

pub fn setCornerCurve(&self, corner_curve: &CALayerCornerCurve)

source

pub fn cornerCurveExpansionFactor(curve: &CALayerCornerCurve) -> CGFloat

source

pub fn borderWidth(&self) -> CGFloat

source

pub fn setBorderWidth(&self, border_width: CGFloat)

source

pub fn opacity(&self) -> c_float

source

pub fn setOpacity(&self, opacity: c_float)

source

pub fn allowsGroupOpacity(&self) -> bool

source

pub fn setAllowsGroupOpacity(&self, allows_group_opacity: bool)

source

pub unsafe fn compositingFilter(&self) -> Option<Retained<AnyObject>>

source

pub unsafe fn setCompositingFilter( &self, compositing_filter: Option<&AnyObject> )

source

pub unsafe fn filters(&self) -> Option<Retained<NSArray>>

source

pub unsafe fn setFilters(&self, filters: Option<&NSArray>)

source

pub unsafe fn backgroundFilters(&self) -> Option<Retained<NSArray>>

source

pub unsafe fn setBackgroundFilters(&self, background_filters: Option<&NSArray>)

source

pub fn shouldRasterize(&self) -> bool

source

pub fn setShouldRasterize(&self, should_rasterize: bool)

source

pub fn rasterizationScale(&self) -> CGFloat

source

pub fn setRasterizationScale(&self, rasterization_scale: CGFloat)

source

pub fn shadowOpacity(&self) -> c_float

source

pub fn setShadowOpacity(&self, shadow_opacity: c_float)

source

pub fn shadowOffset(&self) -> CGSize

source

pub fn setShadowOffset(&self, shadow_offset: CGSize)

source

pub fn shadowRadius(&self) -> CGFloat

source

pub fn setShadowRadius(&self, shadow_radius: CGFloat)

source

pub fn autoresizingMask(&self) -> CAAutoresizingMask

source

pub fn setAutoresizingMask(&self, autoresizing_mask: CAAutoresizingMask)

source

pub fn layoutManager( &self ) -> Option<Retained<ProtocolObject<dyn CALayoutManager>>>

source

pub fn setLayoutManager( &self, layout_manager: Option<&ProtocolObject<dyn CALayoutManager>> )

source

pub fn preferredFrameSize(&self) -> CGSize

source

pub fn setNeedsLayout(&self)

source

pub fn needsLayout(&self) -> bool

source

pub fn layoutIfNeeded(&self)

source

pub fn layoutSublayers(&self)

source

pub fn resizeSublayersWithOldSize(&self, size: CGSize)

source

pub fn resizeWithOldSuperlayerSize(&self, size: CGSize)

source

pub fn defaultActionForKey( event: &NSString ) -> Option<Retained<ProtocolObject<dyn CAAction>>>

source

pub fn actionForKey( &self, event: &NSString ) -> Option<Retained<ProtocolObject<dyn CAAction>>>

source

pub fn actions( &self ) -> Option<Retained<NSDictionary<NSString, ProtocolObject<dyn CAAction>>>>

source

pub fn setActions( &self, actions: Option<&NSDictionary<NSString, ProtocolObject<dyn CAAction>>> )

source

pub fn addAnimation_forKey(&self, anim: &CAAnimation, key: Option<&NSString>)

Available on crate feature CAAnimation only.
source

pub fn removeAllAnimations(&self)

source

pub fn removeAnimationForKey(&self, key: &NSString)

source

pub fn animationKeys(&self) -> Option<Retained<NSArray<NSString>>>

source

pub unsafe fn animationForKey( &self, key: &NSString ) -> Option<Retained<CAAnimation>>

Available on crate feature CAAnimation only.
source

pub fn name(&self) -> Option<Retained<NSString>>

source

pub fn setName(&self, name: Option<&NSString>)

source

pub fn delegate(&self) -> Option<Retained<ProtocolObject<dyn CALayerDelegate>>>

source

pub fn setDelegate( &self, delegate: Option<&ProtocolObject<dyn CALayerDelegate>> )

source

pub unsafe fn style(&self) -> Option<Retained<NSDictionary>>

source

pub unsafe fn setStyle(&self, style: Option<&NSDictionary>)

source

impl CALayer

Methods declared on superclass NSObject

source

pub fn new() -> Retained<Self>

source

impl CALayer

CARemoteLayerServer

source

pub unsafe fn layerWithRemoteClientId(client_id: u32) -> Retained<CALayer>

Available on crate feature CARemoteLayerServer only.
source

impl CALayer

CALayerScrolling

source

pub unsafe fn scrollPoint(&self, p: CGPoint)

Available on crate feature CAScrollLayer only.
source

pub unsafe fn scrollRectToVisible(&self, r: CGRect)

Available on crate feature CAScrollLayer only.
source

pub unsafe fn visibleRect(&self) -> CGRect

Available on crate feature CAScrollLayer only.

Methods from Deref<Target = NSObject>

source

pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !

Handle messages the object doesn’t recognize.

See Apple’s documentation for details.

Methods from Deref<Target = AnyObject>

source

pub fn class(&self) -> &'static AnyClass

Dynamically find the class of this object.

Example

Check that an instance of NSObject has the precise class NSObject.

use objc2::ClassType;
use objc2::runtime::NSObject;

let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());
source

pub unsafe fn get_ivar<T>(&self, name: &str) -> &T
where T: Encode,

👎Deprecated: this is difficult to use correctly, use Ivar::load instead.

Use Ivar::load instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.

source

pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut T
where T: Encode,

👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.

Use Ivar::load_mut instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.