Struct objc2_quartz_core::CAMetalDisplayLink
source · #[repr(C)]pub struct CAMetalDisplayLink { /* private fields */ }Available on crate feature
CAMetalDisplayLink only.Implementations
sourceimpl CAMetalDisplayLink
impl CAMetalDisplayLink
pub unsafe fn initWithMetalLayer( this: Allocated<Self>, layer: &CAMetalLayer ) -> Retained<Self>
Available on crate features
CALayer and CAMetalLayer only.pub unsafe fn addToRunLoop_forMode( &self, runloop: &NSRunLoop, mode: &NSRunLoopMode )
pub unsafe fn removeFromRunLoop_forMode( &self, runloop: &NSRunLoop, mode: &NSRunLoopMode )
pub unsafe fn invalidate(&self)
pub unsafe fn delegate( &self ) -> Option<Retained<ProtocolObject<dyn CAMetalDisplayLinkDelegate>>>
pub unsafe fn setDelegate( &self, delegate: Option<&ProtocolObject<dyn CAMetalDisplayLinkDelegate>> )
pub unsafe fn preferredFrameLatency(&self) -> c_float
pub unsafe fn setPreferredFrameLatency(&self, preferred_frame_latency: c_float)
pub unsafe fn preferredFrameRateRange(&self) -> CAFrameRateRange
Available on crate feature
CAFrameRateRange only.pub unsafe fn setPreferredFrameRateRange( &self, preferred_frame_rate_range: CAFrameRateRange )
Available on crate feature
CAFrameRateRange only.pub unsafe fn isPaused(&self) -> bool
pub unsafe fn setPaused(&self, paused: bool)
Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.