Struct objc2_quartz_core::CASpringAnimation

source ·
#[repr(C)]
pub struct CASpringAnimation { /* private fields */ }
Available on crate feature CAAnimation only.

Implementations

source

impl CASpringAnimation

source

pub unsafe fn mass(&self) -> CGFloat

source

pub unsafe fn setMass(&self, mass: CGFloat)

source

pub unsafe fn stiffness(&self) -> CGFloat

source

pub unsafe fn setStiffness(&self, stiffness: CGFloat)

source

pub unsafe fn damping(&self) -> CGFloat

source

pub unsafe fn setDamping(&self, damping: CGFloat)

source

pub unsafe fn initialVelocity(&self) -> CGFloat

source

pub unsafe fn setInitialVelocity(&self, initial_velocity: CGFloat)

source

pub unsafe fn allowsOverdamping(&self) -> bool

source

pub unsafe fn setAllowsOverdamping(&self, allows_overdamping: bool)

source

pub unsafe fn settlingDuration(&self) -> c_double

source

pub unsafe fn initWithPerceptualDuration_bounce( this: Allocated<Self>, perceptual_duration: c_double, bounce: CGFloat ) -> Retained<Self>

source

pub unsafe fn perceptualDuration(&self) -> c_double

source

pub unsafe fn bounce(&self) -> CGFloat

source

impl CASpringAnimation

Methods declared on superclass CAPropertyAnimation

source

pub unsafe fn animationWithKeyPath(path: Option<&NSString>) -> Retained<Self>

source

impl CASpringAnimation

Methods declared on superclass CAAnimation

source

pub unsafe fn animation() -> Retained<Self>

source

impl CASpringAnimation

Methods declared on superclass NSObject

source

pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>

source

pub unsafe fn new() -> Retained<Self>

Methods from Deref<Target = CABasicAnimation>

source

pub unsafe fn fromValue(&self) -> Option<Retained<AnyObject>>

source

pub unsafe fn setFromValue(&self, from_value: Option<&AnyObject>)

source

pub unsafe fn toValue(&self) -> Option<Retained<AnyObject>>

source

pub unsafe fn setToValue(&self, to_value: Option<&AnyObject>)

source

pub unsafe fn byValue(&self) -> Option<Retained<AnyObject>>

source

pub unsafe fn setByValue(&self, by_value: Option<&AnyObject>)

Methods from Deref<Target = CAPropertyAnimation>

source

pub unsafe fn keyPath(&self) -> Option<Retained<NSString>>

source

pub unsafe fn setKeyPath(&self, key_path: Option<&NSString>)

source

pub unsafe fn isAdditive(&self) -> bool

source

pub unsafe fn setAdditive(&self, additive: bool)

source

pub unsafe fn isCumulative(&self) -> bool

source

pub unsafe fn setCumulative(&self, cumulative: bool)

source

pub unsafe fn valueFunction(&self) -> Option<Retained<CAValueFunction>>

Available on crate feature CAValueFunction only.
source

pub unsafe fn setValueFunction(&self, value_function: Option<&CAValueFunction>)

Available on crate feature CAValueFunction only.

Methods from Deref<Target = CAAnimation>

source

pub unsafe fn shouldArchiveValueForKey(&self, key: &NSString) -> bool

source

pub unsafe fn timingFunction(&self) -> Option<Retained<CAMediaTimingFunction>>

Available on crate feature CAMediaTimingFunction only.
source

pub unsafe fn setTimingFunction( &self, timing_function: Option<&CAMediaTimingFunction> )

Available on crate feature CAMediaTimingFunction only.
source

pub unsafe fn delegate( &self ) -> Option<Retained<ProtocolObject<dyn CAAnimationDelegate>>>

source

pub unsafe fn setDelegate( &self, delegate: Option<&ProtocolObject<dyn CAAnimationDelegate>> )

source

pub unsafe fn isRemovedOnCompletion(&self) -> bool

source

pub unsafe fn setRemovedOnCompletion(&self, removed_on_completion: bool)

source

pub unsafe fn preferredFrameRateRange(&self) -> CAFrameRateRange

Available on crate feature CAFrameRateRange only.
source

pub unsafe fn setPreferredFrameRateRange( &self, preferred_frame_rate_range: CAFrameRateRange )

Available on crate feature CAFrameRateRange only.

Methods from Deref<Target = NSObject>

source

pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !

Handle messages the object doesn’t recognize.

See Apple’s documentation for details.

Methods from Deref<Target = AnyObject>

source

pub fn class(&self) -> &'static AnyClass

Dynamically find the class of this object.

Example

Check that an instance of NSObject has the precise class NSObject.

use objc2::ClassType;
use objc2::runtime::NSObject;

let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());
source

pub unsafe fn get_ivar<T>(&self, name: &str) -> &T
where T: Encode,

👎Deprecated: this is difficult to use correctly, use Ivar::load instead.

Use Ivar::load instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.

source

pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut T
where T: Encode,

👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.

Use Ivar::load_mut instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.