Struct objc2_quartz_core::CAEmitterCell
source · #[repr(C)]pub struct CAEmitterCell { /* private fields */ }Available on crate feature
CAEmitterCell only.Implementations
sourceimpl CAEmitterCell
impl CAEmitterCell
pub unsafe fn emitterCell() -> Retained<Self>
pub unsafe fn defaultValueForKey(key: &NSString) -> Option<Retained<AnyObject>>
pub unsafe fn shouldArchiveValueForKey(&self, key: &NSString) -> bool
pub unsafe fn name(&self) -> Option<Retained<NSString>>
pub unsafe fn setName(&self, name: Option<&NSString>)
pub unsafe fn isEnabled(&self) -> bool
pub unsafe fn setEnabled(&self, enabled: bool)
pub unsafe fn birthRate(&self) -> c_float
pub unsafe fn setBirthRate(&self, birth_rate: c_float)
pub unsafe fn lifetime(&self) -> c_float
pub unsafe fn setLifetime(&self, lifetime: c_float)
pub unsafe fn lifetimeRange(&self) -> c_float
pub unsafe fn setLifetimeRange(&self, lifetime_range: c_float)
pub unsafe fn emissionLatitude(&self) -> CGFloat
pub unsafe fn setEmissionLatitude(&self, emission_latitude: CGFloat)
pub unsafe fn emissionLongitude(&self) -> CGFloat
pub unsafe fn setEmissionLongitude(&self, emission_longitude: CGFloat)
pub unsafe fn emissionRange(&self) -> CGFloat
pub unsafe fn setEmissionRange(&self, emission_range: CGFloat)
pub unsafe fn velocity(&self) -> CGFloat
pub unsafe fn setVelocity(&self, velocity: CGFloat)
pub unsafe fn velocityRange(&self) -> CGFloat
pub unsafe fn setVelocityRange(&self, velocity_range: CGFloat)
pub unsafe fn xAcceleration(&self) -> CGFloat
pub unsafe fn setXAcceleration(&self, x_acceleration: CGFloat)
pub unsafe fn yAcceleration(&self) -> CGFloat
pub unsafe fn setYAcceleration(&self, y_acceleration: CGFloat)
pub unsafe fn zAcceleration(&self) -> CGFloat
pub unsafe fn setZAcceleration(&self, z_acceleration: CGFloat)
pub unsafe fn scale(&self) -> CGFloat
pub unsafe fn setScale(&self, scale: CGFloat)
pub unsafe fn scaleRange(&self) -> CGFloat
pub unsafe fn setScaleRange(&self, scale_range: CGFloat)
pub unsafe fn scaleSpeed(&self) -> CGFloat
pub unsafe fn setScaleSpeed(&self, scale_speed: CGFloat)
pub unsafe fn spin(&self) -> CGFloat
pub unsafe fn setSpin(&self, spin: CGFloat)
pub unsafe fn spinRange(&self) -> CGFloat
pub unsafe fn setSpinRange(&self, spin_range: CGFloat)
pub unsafe fn redRange(&self) -> c_float
pub unsafe fn setRedRange(&self, red_range: c_float)
pub unsafe fn greenRange(&self) -> c_float
pub unsafe fn setGreenRange(&self, green_range: c_float)
pub unsafe fn blueRange(&self) -> c_float
pub unsafe fn setBlueRange(&self, blue_range: c_float)
pub unsafe fn alphaRange(&self) -> c_float
pub unsafe fn setAlphaRange(&self, alpha_range: c_float)
pub unsafe fn redSpeed(&self) -> c_float
pub unsafe fn setRedSpeed(&self, red_speed: c_float)
pub unsafe fn greenSpeed(&self) -> c_float
pub unsafe fn setGreenSpeed(&self, green_speed: c_float)
pub unsafe fn blueSpeed(&self) -> c_float
pub unsafe fn setBlueSpeed(&self, blue_speed: c_float)
pub unsafe fn alphaSpeed(&self) -> c_float
pub unsafe fn setAlphaSpeed(&self, alpha_speed: c_float)
pub unsafe fn contents(&self) -> Option<Retained<AnyObject>>
pub unsafe fn setContents(&self, contents: Option<&AnyObject>)
pub unsafe fn contentsRect(&self) -> CGRect
pub unsafe fn setContentsRect(&self, contents_rect: CGRect)
pub unsafe fn contentsScale(&self) -> CGFloat
pub unsafe fn setContentsScale(&self, contents_scale: CGFloat)
pub unsafe fn minificationFilter(&self) -> Retained<NSString>
pub unsafe fn setMinificationFilter(&self, minification_filter: &NSString)
pub unsafe fn magnificationFilter(&self) -> Retained<NSString>
pub unsafe fn setMagnificationFilter(&self, magnification_filter: &NSString)
pub unsafe fn minificationFilterBias(&self) -> c_float
pub unsafe fn setMinificationFilterBias( &self, minification_filter_bias: c_float )
pub unsafe fn emitterCells(&self) -> Option<Retained<NSArray<CAEmitterCell>>>
pub unsafe fn setEmitterCells( &self, emitter_cells: Option<&NSArray<CAEmitterCell>> )
pub unsafe fn style(&self) -> Option<Retained<NSDictionary>>
pub unsafe fn setStyle(&self, style: Option<&NSDictionary>)
Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.