Struct objc2_quartz_core::CALayer
source · #[repr(C)]pub struct CALayer { /* private fields */ }Available on crate feature
CALayer only.Implementations
sourceimpl CALayer
impl CALayer
CAConstraintLayoutManager
pub unsafe fn constraints(&self) -> Option<Retained<NSArray<CAConstraint>>>
Available on crate feature
CAConstraintLayoutManager only.pub unsafe fn setConstraints(&self, constraints: Option<&NSArray<CAConstraint>>)
Available on crate feature
CAConstraintLayoutManager only.pub unsafe fn addConstraint(&self, c: &CAConstraint)
Available on crate feature
CAConstraintLayoutManager only.sourceimpl CALayer
impl CALayer
pub fn layer() -> Retained<Self>
pub fn init(this: Allocated<Self>) -> Retained<Self>
pub unsafe fn initWithLayer( this: Allocated<Self>, layer: &AnyObject ) -> Retained<Self>
pub unsafe fn presentationLayer(&self) -> Option<Retained<Self>>
pub unsafe fn modelLayer(&self) -> Retained<Self>
pub unsafe fn defaultValueForKey(key: &NSString) -> Option<Retained<AnyObject>>
pub unsafe fn needsDisplayForKey(key: &NSString) -> bool
pub unsafe fn shouldArchiveValueForKey(&self, key: &NSString) -> bool
pub fn bounds(&self) -> CGRect
pub fn setBounds(&self, bounds: CGRect)
pub fn position(&self) -> CGPoint
pub fn setPosition(&self, position: CGPoint)
pub fn zPosition(&self) -> CGFloat
pub fn setZPosition(&self, z_position: CGFloat)
pub fn anchorPoint(&self) -> CGPoint
pub fn setAnchorPoint(&self, anchor_point: CGPoint)
pub fn anchorPointZ(&self) -> CGFloat
pub fn setAnchorPointZ(&self, anchor_point_z: CGFloat)
pub fn transform(&self) -> CATransform3D
Available on crate feature
CATransform3D only.pub fn setTransform(&self, transform: CATransform3D)
Available on crate feature
CATransform3D only.pub fn frame(&self) -> CGRect
pub fn setFrame(&self, frame: CGRect)
pub fn isHidden(&self) -> bool
pub fn setHidden(&self, hidden: bool)
pub fn isDoubleSided(&self) -> bool
pub fn setDoubleSided(&self, double_sided: bool)
pub fn isGeometryFlipped(&self) -> bool
pub fn setGeometryFlipped(&self, geometry_flipped: bool)
pub fn contentsAreFlipped(&self) -> bool
pub fn superlayer(&self) -> Option<Retained<CALayer>>
pub fn removeFromSuperlayer(&self)
pub unsafe fn sublayers(&self) -> Option<Retained<NSArray<CALayer>>>
pub unsafe fn setSublayers(&self, sublayers: Option<&NSArray<CALayer>>)
pub fn addSublayer(&self, layer: &CALayer)
pub fn insertSublayer_atIndex(&self, layer: &CALayer, idx: c_uint)
pub fn insertSublayer_below(&self, layer: &CALayer, sibling: Option<&CALayer>)
pub fn insertSublayer_above(&self, layer: &CALayer, sibling: Option<&CALayer>)
pub unsafe fn replaceSublayer_with( &self, old_layer: &CALayer, new_layer: &CALayer )
pub fn sublayerTransform(&self) -> CATransform3D
Available on crate feature
CATransform3D only.pub fn setSublayerTransform(&self, sublayer_transform: CATransform3D)
Available on crate feature
CATransform3D only.pub fn mask(&self) -> Option<Retained<CALayer>>
pub unsafe fn setMask(&self, mask: Option<&CALayer>)
pub fn masksToBounds(&self) -> bool
pub fn setMasksToBounds(&self, masks_to_bounds: bool)
pub fn convertPoint_fromLayer(&self, p: CGPoint, l: Option<&CALayer>) -> CGPoint
pub fn convertPoint_toLayer(&self, p: CGPoint, l: Option<&CALayer>) -> CGPoint
pub fn convertRect_fromLayer(&self, r: CGRect, l: Option<&CALayer>) -> CGRect
pub fn convertRect_toLayer(&self, r: CGRect, l: Option<&CALayer>) -> CGRect
pub fn convertTime_fromLayer( &self, t: c_double, l: Option<&CALayer> ) -> c_double
pub fn convertTime_toLayer(&self, t: c_double, l: Option<&CALayer>) -> c_double
pub fn hitTest(&self, p: CGPoint) -> Option<Retained<CALayer>>
pub fn containsPoint(&self, p: CGPoint) -> bool
pub unsafe fn contents(&self) -> Option<Retained<AnyObject>>
pub unsafe fn setContents(&self, contents: Option<&AnyObject>)
pub fn contentsRect(&self) -> CGRect
pub fn setContentsRect(&self, contents_rect: CGRect)
pub fn contentsGravity(&self) -> Retained<CALayerContentsGravity>
pub fn setContentsGravity(&self, contents_gravity: &CALayerContentsGravity)
pub fn contentsScale(&self) -> CGFloat
pub fn setContentsScale(&self, contents_scale: CGFloat)
pub fn contentsCenter(&self) -> CGRect
pub fn setContentsCenter(&self, contents_center: CGRect)
pub fn contentsFormat(&self) -> Retained<CALayerContentsFormat>
pub fn setContentsFormat(&self, contents_format: &CALayerContentsFormat)
pub unsafe fn wantsExtendedDynamicRangeContent(&self) -> bool
pub unsafe fn setWantsExtendedDynamicRangeContent( &self, wants_extended_dynamic_range_content: bool )
pub fn minificationFilter(&self) -> Retained<CALayerContentsFilter>
pub fn setMinificationFilter(&self, minification_filter: &CALayerContentsFilter)
pub fn magnificationFilter(&self) -> Retained<CALayerContentsFilter>
pub fn setMagnificationFilter( &self, magnification_filter: &CALayerContentsFilter )
pub fn minificationFilterBias(&self) -> c_float
pub fn setMinificationFilterBias(&self, minification_filter_bias: c_float)
pub fn isOpaque(&self) -> bool
pub fn setOpaque(&self, opaque: bool)
pub fn display(&self)
pub fn setNeedsDisplay(&self)
pub fn setNeedsDisplayInRect(&self, r: CGRect)
pub fn needsDisplay(&self) -> bool
pub fn displayIfNeeded(&self)
pub fn needsDisplayOnBoundsChange(&self) -> bool
pub fn setNeedsDisplayOnBoundsChange( &self, needs_display_on_bounds_change: bool )
pub fn drawsAsynchronously(&self) -> bool
pub fn setDrawsAsynchronously(&self, draws_asynchronously: bool)
pub fn edgeAntialiasingMask(&self) -> CAEdgeAntialiasingMask
pub fn setEdgeAntialiasingMask( &self, edge_antialiasing_mask: CAEdgeAntialiasingMask )
pub fn allowsEdgeAntialiasing(&self) -> bool
pub fn setAllowsEdgeAntialiasing(&self, allows_edge_antialiasing: bool)
pub fn cornerRadius(&self) -> CGFloat
pub fn setCornerRadius(&self, corner_radius: CGFloat)
pub fn maskedCorners(&self) -> CACornerMask
pub fn setMaskedCorners(&self, masked_corners: CACornerMask)
pub fn cornerCurve(&self) -> Retained<CALayerCornerCurve>
pub fn setCornerCurve(&self, corner_curve: &CALayerCornerCurve)
pub fn cornerCurveExpansionFactor(curve: &CALayerCornerCurve) -> CGFloat
pub fn borderWidth(&self) -> CGFloat
pub fn setBorderWidth(&self, border_width: CGFloat)
pub fn opacity(&self) -> c_float
pub fn setOpacity(&self, opacity: c_float)
pub fn allowsGroupOpacity(&self) -> bool
pub fn setAllowsGroupOpacity(&self, allows_group_opacity: bool)
pub unsafe fn compositingFilter(&self) -> Option<Retained<AnyObject>>
pub unsafe fn setCompositingFilter( &self, compositing_filter: Option<&AnyObject> )
pub unsafe fn filters(&self) -> Option<Retained<NSArray>>
pub unsafe fn setFilters(&self, filters: Option<&NSArray>)
pub unsafe fn backgroundFilters(&self) -> Option<Retained<NSArray>>
pub unsafe fn setBackgroundFilters(&self, background_filters: Option<&NSArray>)
pub fn shouldRasterize(&self) -> bool
pub fn setShouldRasterize(&self, should_rasterize: bool)
pub fn rasterizationScale(&self) -> CGFloat
pub fn setRasterizationScale(&self, rasterization_scale: CGFloat)
pub fn shadowOpacity(&self) -> c_float
pub fn setShadowOpacity(&self, shadow_opacity: c_float)
pub fn shadowOffset(&self) -> CGSize
pub fn setShadowOffset(&self, shadow_offset: CGSize)
pub fn shadowRadius(&self) -> CGFloat
pub fn setShadowRadius(&self, shadow_radius: CGFloat)
pub fn autoresizingMask(&self) -> CAAutoresizingMask
pub fn setAutoresizingMask(&self, autoresizing_mask: CAAutoresizingMask)
pub fn layoutManager( &self ) -> Option<Retained<ProtocolObject<dyn CALayoutManager>>>
pub fn setLayoutManager( &self, layout_manager: Option<&ProtocolObject<dyn CALayoutManager>> )
pub fn preferredFrameSize(&self) -> CGSize
pub fn setNeedsLayout(&self)
pub fn needsLayout(&self) -> bool
pub fn layoutIfNeeded(&self)
pub fn layoutSublayers(&self)
pub fn resizeSublayersWithOldSize(&self, size: CGSize)
pub fn resizeWithOldSuperlayerSize(&self, size: CGSize)
pub fn defaultActionForKey( event: &NSString ) -> Option<Retained<ProtocolObject<dyn CAAction>>>
pub fn actionForKey( &self, event: &NSString ) -> Option<Retained<ProtocolObject<dyn CAAction>>>
pub fn actions( &self ) -> Option<Retained<NSDictionary<NSString, ProtocolObject<dyn CAAction>>>>
pub fn setActions( &self, actions: Option<&NSDictionary<NSString, ProtocolObject<dyn CAAction>>> )
pub fn addAnimation_forKey(&self, anim: &CAAnimation, key: Option<&NSString>)
Available on crate feature
CAAnimation only.pub fn removeAllAnimations(&self)
pub fn removeAnimationForKey(&self, key: &NSString)
pub fn animationKeys(&self) -> Option<Retained<NSArray<NSString>>>
pub unsafe fn animationForKey( &self, key: &NSString ) -> Option<Retained<CAAnimation>>
Available on crate feature
CAAnimation only.pub fn name(&self) -> Option<Retained<NSString>>
pub fn setName(&self, name: Option<&NSString>)
pub fn delegate(&self) -> Option<Retained<ProtocolObject<dyn CALayerDelegate>>>
pub fn setDelegate( &self, delegate: Option<&ProtocolObject<dyn CALayerDelegate>> )
pub unsafe fn style(&self) -> Option<Retained<NSDictionary>>
pub unsafe fn setStyle(&self, style: Option<&NSDictionary>)
sourceimpl CALayer
impl CALayer
CARemoteLayerServer
pub unsafe fn layerWithRemoteClientId(client_id: u32) -> Retained<CALayer>
Available on crate feature
CARemoteLayerServer only.sourceimpl CALayer
impl CALayer
CALayerScrolling
pub unsafe fn scrollPoint(&self, p: CGPoint)
Available on crate feature
CAScrollLayer only.pub unsafe fn scrollRectToVisible(&self, r: CGRect)
Available on crate feature
CAScrollLayer only.pub unsafe fn visibleRect(&self) -> CGRect
Available on crate feature
CAScrollLayer only.Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.