Struct objc2_quartz_core::CASpringAnimation
source · #[repr(C)]pub struct CASpringAnimation { /* private fields */ }Available on crate feature
CAAnimation only.Implementations
sourceimpl CASpringAnimation
impl CASpringAnimation
pub unsafe fn mass(&self) -> CGFloat
pub unsafe fn setMass(&self, mass: CGFloat)
pub unsafe fn stiffness(&self) -> CGFloat
pub unsafe fn setStiffness(&self, stiffness: CGFloat)
pub unsafe fn damping(&self) -> CGFloat
pub unsafe fn setDamping(&self, damping: CGFloat)
pub unsafe fn initialVelocity(&self) -> CGFloat
pub unsafe fn setInitialVelocity(&self, initial_velocity: CGFloat)
pub unsafe fn allowsOverdamping(&self) -> bool
pub unsafe fn setAllowsOverdamping(&self, allows_overdamping: bool)
pub unsafe fn settlingDuration(&self) -> c_double
pub unsafe fn initWithPerceptualDuration_bounce( this: Allocated<Self>, perceptual_duration: c_double, bounce: CGFloat ) -> Retained<Self>
pub unsafe fn perceptualDuration(&self) -> c_double
pub unsafe fn bounce(&self) -> CGFloat
sourceimpl CASpringAnimation
impl CASpringAnimation
Methods declared on superclass CAPropertyAnimation
pub unsafe fn animationWithKeyPath(path: Option<&NSString>) -> Retained<Self>
sourceimpl CASpringAnimation
impl CASpringAnimation
Methods declared on superclass CAAnimation
Methods from Deref<Target = CABasicAnimation>
pub unsafe fn fromValue(&self) -> Option<Retained<AnyObject>>
pub unsafe fn setFromValue(&self, from_value: Option<&AnyObject>)
pub unsafe fn toValue(&self) -> Option<Retained<AnyObject>>
pub unsafe fn setToValue(&self, to_value: Option<&AnyObject>)
pub unsafe fn byValue(&self) -> Option<Retained<AnyObject>>
pub unsafe fn setByValue(&self, by_value: Option<&AnyObject>)
Methods from Deref<Target = CAPropertyAnimation>
pub unsafe fn keyPath(&self) -> Option<Retained<NSString>>
pub unsafe fn setKeyPath(&self, key_path: Option<&NSString>)
pub unsafe fn isAdditive(&self) -> bool
pub unsafe fn setAdditive(&self, additive: bool)
pub unsafe fn isCumulative(&self) -> bool
pub unsafe fn setCumulative(&self, cumulative: bool)
pub unsafe fn valueFunction(&self) -> Option<Retained<CAValueFunction>>
Available on crate feature
CAValueFunction only.pub unsafe fn setValueFunction(&self, value_function: Option<&CAValueFunction>)
Available on crate feature
CAValueFunction only.Methods from Deref<Target = CAAnimation>
pub unsafe fn shouldArchiveValueForKey(&self, key: &NSString) -> bool
pub unsafe fn timingFunction(&self) -> Option<Retained<CAMediaTimingFunction>>
Available on crate feature
CAMediaTimingFunction only.pub unsafe fn setTimingFunction( &self, timing_function: Option<&CAMediaTimingFunction> )
Available on crate feature
CAMediaTimingFunction only.pub unsafe fn delegate( &self ) -> Option<Retained<ProtocolObject<dyn CAAnimationDelegate>>>
pub unsafe fn setDelegate( &self, delegate: Option<&ProtocolObject<dyn CAAnimationDelegate>> )
pub unsafe fn isRemovedOnCompletion(&self) -> bool
pub unsafe fn setRemovedOnCompletion(&self, removed_on_completion: bool)
pub unsafe fn preferredFrameRateRange(&self) -> CAFrameRateRange
Available on crate feature
CAFrameRateRange only.pub unsafe fn setPreferredFrameRateRange( &self, preferred_frame_rate_range: CAFrameRateRange )
Available on crate feature
CAFrameRateRange only.Methods from Deref<Target = NSObject>
sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
sourcepub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load_mut instead.
pub unsafe fn get_mut_ivar<T>(&mut self, name: &str) -> &mut Twhere
T: Encode,
Ivar::load_mut instead.Use Ivar::load_mut instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.